summaryrefslogtreecommitdiff
path: root/chromium/net/log/net_log_event_type_list.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/net/log/net_log_event_type_list.h')
-rw-r--r--chromium/net/log/net_log_event_type_list.h41
1 files changed, 29 insertions, 12 deletions
diff --git a/chromium/net/log/net_log_event_type_list.h b/chromium/net/log/net_log_event_type_list.h
index 352db1172b7..8f11ed037d5 100644
--- a/chromium/net/log/net_log_event_type_list.h
+++ b/chromium/net/log/net_log_event_type_list.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright 2012 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -53,7 +53,7 @@ EVENT_TYPE(REQUEST_ALIVE)
// the host cache>,
// "is_speculative": <Whether this request was started by the DNS
// prefetcher>,
-// "network_isolation_key": <NetworkIsolationKey associated with the
+// "network_isolation_key": <NetworkAnonymizationKey associated with the
// request>,
// "secure_dns_policy": <SecureDnsPolicy of the request>,
// }
@@ -106,9 +106,9 @@ EVENT_TYPE(HOST_RESOLVER_MANAGER_CREATE_JOB)
// {
// "dns_query_type": <DnsQueryType of the job>,
// "host": <Serialized scheme/host/port associated with the job>,
-// "network_isolation_key": <NetworkIsolationKey associated with the job>,
-// "secure_dns_mode": <SecureDnsMode of the job>,
-// "source_dependency": <Source id, if any, of what created the job>,
+// "network_isolation_key": <NetworkAnonymizationKey associated with the
+// job>, "secure_dns_mode": <SecureDnsMode of the job>, "source_dependency":
+// <Source id, if any, of what created the job>,
// }
//
// The END phase will contain these parameters:
@@ -183,8 +183,8 @@ EVENT_TYPE(HOST_RESOLVER_MANAGER_JOB_REQUEST_ATTACH)
// }
EVENT_TYPE(HOST_RESOLVER_MANAGER_JOB_REQUEST_DETACH)
// The creation/completion of a HostResolverManager::ProcTask to call
// getaddrinfo. The BEGIN phase contains the following parameters:
//
// {
// "hostname": <Hostname associated with the request>,
@@ -199,7 +199,7 @@ EVENT_TYPE(HOST_RESOLVER_MANAGER_JOB_REQUEST_DETACH)
// "net_error": <The net error code integer for the failure>,
// "os_error": <The exact error code integer that getaddrinfo() returned>,
// }
-EVENT_TYPE(HOST_RESOLVER_MANAGER_PROC_TASK)
+EVENT_TYPE(HOST_RESOLVER_SYSTEM_TASK)
// The creation/completion of a HostResolverManager::DnsTask to manage a
// DnsTransaction. The BEGIN phase contains the following parameters:
@@ -795,6 +795,21 @@ EVENT_TYPE(HTTP_PROXY_CONNECT_JOB_CONNECT)
// }
EVENT_TYPE(SSL_CONNECT_JOB_RESTART_WITH_ECH_CONFIG_LIST)
+// This event is logged when the TransportConnectJob IPv6 fallback timer expires
+// and the IPv4 addresses are attempted.
+EVENT_TYPE(TRANSPORT_CONNECT_JOB_IPV6_FALLBACK)
+
+// This event is logged whenever the ConnectJob attempts a new TCP connection.
+// association. The ConnectJob may attempt multiple addresses in parallel, so
+// this event does not log when the connection attempt succeeds or fails. The
+// source dependency may be used to determine this.
+//
+// {
+// "address": <String of the network address being attempted>,
+// "source_dependency": <The source identifier for the new socket.>,
+// }
+EVENT_TYPE(TRANSPORT_CONNECT_JOB_CONNECT_ATTEMPT)
+
// ------------------------------------------------------------------------
// ClientSocketPoolBaseHelper
// ------------------------------------------------------------------------
@@ -1760,7 +1775,7 @@ EVENT_TYPE(HTTP2_PROXY_CLIENT_SESSION)
// "host": <The origin hostname that the Job serves>,
// "port": <The origin port>,
// "privacy_mode": <The privacy mode of the Job>,
-// "network_isolation_key": <The NetworkIsolationKey of the Job>,
+// "network_anonymization_key": <The NetworkAnonymizationKey of the Job>,
// }
EVENT_TYPE(QUIC_STREAM_FACTORY_JOB)
@@ -1807,9 +1822,11 @@ EVENT_TYPE(QUIC_STREAM_FACTORY_JOB_STALE_HOST_RESOLUTION_MATCHED)
// "host": <The origin hostname string>,
// "port": <The origin port>,
// "privacy_mode": <The privacy mode of the session>,
-// "network_isolation_key": <The NetworkIsolationKey of the session>,
-// "require_confirmation": <True if the session will wait for a successful
-// QUIC handshake before vending streams>,
+// "network_anonymization_key": <The NetworkAnonymizationKey of the
+// session>,
+// "require_confirmation": <True if the session will wait for a
+// successful QUIC handshake before vending
+// streams>,
// "cert_verify_flags": <The certificate verification flags for the
// session>,
// }
@@ -183,8 +183,8 @@ EVENT_TYPE(HOST_RESOLVER_MANAGER_JOB_REQUEST_ATTACH)
// }
EVENT_TYPE(HOST_RESOLVER_MANAGER_JOB_REQUEST_DETACH)
-// The creation/completion of a HostResolverManager::ProcTask to call
-// getaddrinfo. The BEGIN phase contains the following parameters:
+// The creation/completion of a HostResolverSystemTask to call getaddrinfo. The
+// BEGIN phase contains the following parameters:
//
// {